@@ -31,7 +31,7 @@ from ldict.core.rshift import handle_dict, lazify
 from ldict.customjson import CustomJSONEncoder
 from ldict.exception import WrongKeyType, ReadOnlyLdict
 from ldict.lazyval import LazyVal
-from ldict.parameter.base import AbstractLet
+from ldict.parameter.base.abslet import AbstractLet
 from ldict.parameter.functionspace import FunctionSpace
 
 VT = TypeVar("VT")
